/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable
 * law or agreed to in writing, software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License
 * for the specific language governing permissions and limitations under the License.
 */

package javax.portlet.faces.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/** The PreDestroy annotation is used on methods as a callback notification to signal
 * that the instance is in the process of being removed by the bridge from
 * the bridge request scope. This method complements one using
 * <code>javax.annotation.PreDestroy</code> to allow the object to release resources
 * that it has been holding. It exists because the existing
 * <code>javax.annotation.PreDestroy</code> method must be ignored as it is called
 * by the container even though the bridge continues to manage the object in its
 * request scope. The method on which the PreDestroy annotation is applied MUST
 * fulfill all of the following criteria - The method MUST NOT have any parameters -
 * The return type of the method MUST be void. - The method MUST NOT throw a checked
 * exception. - The method on which PreDestroy is applied MUST be public. - The
 * method MUST NOT be static. - The method MAY be final. - If the method throws an
 * unchecked exception it is ignored.
 */

@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.METHOD})
public @interface BridgePreDestroy {
}
