/* Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.myfaces.portlet.faces.application;


import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.io.StringWriter;

import java.util.Map;

import java.util.concurrent.ConcurrentHashMap;

import javax.faces.FacesException;
import javax.faces.application.StateManager;
import javax.faces.application.StateManagerWrapper;
import javax.faces.component.UIComponent;
import javax.faces.component.UIViewRoot;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;

import javax.faces.render.RenderKit;
import javax.faces.render.RenderKitWrapper;
import javax.faces.render.ResponseStateManager;

import javax.portlet.faces.Bridge;
import javax.portlet.faces.BridgeUtil;

import org.apache.myfaces.portlet.faces.bridge.BridgeImpl;

public class PortletRenderKitWrapperImpl
  extends RenderKitWrapper
{
  private RenderKit mDelegatee = null;
  private ResponseStateManager mRsm = null;

  public PortletRenderKitWrapperImpl(RenderKit rk)
  {
    mDelegatee = rk;

  }

  public ResponseStateManager getResponseStateManager()
  {
    FacesContext ctx = FacesContext.getCurrentInstance();
    
    if (BridgeUtil.getPortletRequestPhase() != Bridge.PortletPhase.RENDER_PHASE || 
        ctx.getExternalContext().getRequestMap().get(BridgeImpl.SAVED_VIEW_STATE) == null)
    {
      return super.getResponseStateManager();
    }
    
    if (mRsm == null)
    {
      mRsm = new PortletResponseStateManagerImpl(super.getResponseStateManager());
    }
    
    return mRsm;
  }
  
  public RenderKit getWrapped()
  {
    return mDelegatee;
  }
  
}
