/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable
 * law or agreed to in writing, software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License
 * for the specific language governing permissions and limitations under the License.
 */

package org.apache.myfaces.portlet.faces.context;

import javax.faces.context.ExceptionHandler;
import javax.faces.context.ExceptionHandlerFactory;
import javax.portlet.faces.BridgeUtil;

import org.apache.myfaces.shared_portlet.context.ExceptionHandlerImpl;

public class PortletExceptionHanderFactoryImpl extends ExceptionHandlerFactory
{
  private ExceptionHandlerFactory mWrapped;
  
  public PortletExceptionHanderFactoryImpl(ExceptionHandlerFactory wrapped)
  {
    this.mWrapped = wrapped;
  }

  @Override
  public ExceptionHandlerFactory getWrapped()
  {
    return mWrapped;
  }

  @Override
  public ExceptionHandler getExceptionHandler()
  {
    if(BridgeUtil.isPortletRequest())
    {
      //This is an exception handler which does not write to the output
      //stream as this would cause problems in a portlet environment
      
      //TODO: Maybe add a mechanism where the data IS written out to the
      //portlet during the render phase.
      return new ExceptionHandlerImpl();
    }
    
    return getWrapped().getExceptionHandler();
  }  
}
