/* Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.myfaces.portlet.faces.context;

import java.util.ArrayList;
import java.util.Collection;

import java.util.Iterator;
import java.util.List;

import javax.faces.component.ContextCallback;
import javax.faces.component.NamingContainer;
import javax.faces.component.UIComponent;
import javax.faces.component.UIViewRoot;
import javax.faces.context.FacesContext;
import javax.faces.context.PartialViewContext;
import javax.faces.context.PartialViewContextWrapper;

import javax.portlet.faces.BridgeUtil;


public class PortletPartialViewContextImpl extends PartialViewContextWrapper
{

  private PartialViewContext mWrapped;
  
  private Collection<String> mExecuteIds;
  private Collection<String> mRenderIds;

  // ----------------------------------------------------------- Constructors


  public PortletPartialViewContextImpl(PartialViewContext ctx)
  {
    mWrapped = ctx;
  }


  // ---------------------------------------------- Methods from PartialViewContext

  @Override
  public PartialViewContext getWrapped()
  {
      return mWrapped;
  }


  /**
   * @see javax.faces.context.PartialViewContext#getExecuteIds()
   */
  @Override
  public Collection<String> getExecuteIds()
  {
    // Merely delegate is not a portlet request
    if (!BridgeUtil.isPortletRequest())
    {
      return super.getExecuteIds();
    }
    
    
    if (mExecuteIds != null) {
      return mExecuteIds;
    }
    if (!super.isExecuteAll())
    {
      mExecuteIds = fixUpClientIds(super.getExecuteIds());
      return mExecuteIds;
    }
    else
    {
      return super.getExecuteIds();
    }
  }

  /**
   * @see javax.faces.context.PartialViewContext#getRenderIds()
   */
  @Override
  public Collection<String> getRenderIds()
  {
    // Merely delegate is not a portlet request
    if (!BridgeUtil.isPortletRequest())
    {
      return super.getRenderIds();
    }
    
    if (mRenderIds != null) {
      return mRenderIds;
    }
    
    if (!super.isRenderAll())
    {
      mRenderIds = fixUpClientIds(super.getRenderIds());
      return mRenderIds;
    }
    else
    {
      return super.getRenderIds();
    }
  }


  /**
   * @see javax.faces.context.PartialViewContext#release()
   */
  public void release()
  {
    super.release();

    mExecuteIds = null;
    mRenderIds = null;
  }


  /* Ugh -- 2.0 bug -- this method not in the wrapper */
  public void setPartialRequest(boolean b)
  {
    getWrapped().setPartialRequest(b);
  }
  
  private Collection<String> fixUpClientIds(Collection<String> ids)
  {
    FacesContext ctx = FacesContext.getCurrentInstance();
    String vrId = ctx.getViewRoot().getContainerClientId(ctx);
    
    ArrayList<String> fixedIds = new ArrayList<String>(ids.size());
    for (String id : ids)
    {
      fixedIds.add(fixUpClientId(id, vrId));
    }
    return fixedIds;
  }
  
  private String fixUpClientId(String id, String bridgeVRPrefix)
  {
    if (!id.startsWith("@") && !id.startsWith(bridgeVRPrefix))
    {
      id = new StringBuffer(bridgeVRPrefix).append(":").append(id).toString();
    }
    return id;
  }
  
 /* 
  private String fixUpClientId(String id)
  {
    FacesContext ctx = FacesContext.getCurrentInstance();
    UIViewRoot vr = ctx.getViewRoot();
    
    // First ask whether id is a valid client id by searching for it.
    if (vr.invokeOnComponent(ctx, id, new ContextCallback() {
         public void invokeContextCallback(FacesContext context,
                                       UIComponent component)
         {
         }
        }))
    {
      return id;
    }
      
    // Otherwise assume its the actual id -- find it and get its client id
    UIComponent comp = findComponent(vr, id);
    if (comp != null)
    {
      return comp.getClientId();
    }
    else
    {
      return id;  // Don't know whether this id is valid or not but forge ahead
    }
  }
    
  private UIComponent findComponent(UIComponent base, String searchId)
  {
    if (searchId.equals(base.getId())) {
        return base;
    }
    UIComponent result = null;
    
    // Search through our facets and children
    for (Iterator i = base.getFacetsAndChildren(); i.hasNext(); )
    {
      result = findComponent((UIComponent) i.next(), searchId);
      
      if (result != null) break;
    }
    return result;

  }
*/
    
}
